@@ -4,6 +4,9 @@ from sqlalchemy.engine import create_engine
 from sqlalchemy.orm.session import Session
 
 Base = declarative_base()
+# generate tables
+# engine = create_engine("mysql+pymysql://root:Wangchenyu2012@127.0.0.1:3306/p3")
+# Base.metadata.create_all(engine)
 
 
 def database_toast(issue: int, name_cn: str, name: str, key: str, value: str):
@@ -12,10 +15,14 @@ def database_toast(issue: int, name_cn: str, name: str, key: str, value: str):
 
 
 def get_session_sport():
-    path_db = r'C:\Users\Wangjulong\tensorflows\p3.db'
-    path_str = 'sqlite:///' + path_db
-    db_engine = create_engine(path_str, echo=False)
-    session = Session(db_engine)
+    # path_db = r'C:\Users\Wangjulong\tensorflows\p3.db'
+    # path_str = 'sqlite:///' + path_db
+    # db_engine = create_engine(path_str, echo=False)
+    # session = Session(db_engine)
+    # return session
+    # mysql+pymysql://<username>:<password>@<host>/<dbname>[?<options>]
+    engine = create_engine("mysql+pymysql://root:Wangchenyu2012@127.0.0.1:3306/p3")
+    session = Session(engine)
     return session
 
 
@@ -37,7 +44,23 @@ class SportNumber(Base):
         session = get_session_sport()
         i = session.query(cls).all()
         session.close()
-        return [x.issue for x in i]
+        result = [x.issue for x in i]
+        result.sort()
+        return result
+
+    @classmethod
+    def get_previous3_issues(cls, issue_now):
+        all_issues = cls.get_issues()
+        issue_now = int(issue_now)
+        index_now = all_issues.index(issue_now)
+        return all_issues[index_now - 3: index_now]
+
+    @classmethod
+    def get_next3_issues(cls, issue_now):
+        all_issues = cls.get_issues()
+        issue_now = int(issue_now)
+        index_now = all_issues.index(issue_now)
+        return all_issues[index_now + 1: index_now + 4]
 
     @classmethod
     def get_all(cls):
@@ -78,8 +101,8 @@ class SportNumber(Base):
 class SportConfig(Base):
     __tablename__ = 'configs'
 
-    name = Column(String, primary_key=True)
-    value = Column(String)
+    name = Column(String(50), primary_key=True)
+    value = Column(String(50))
 
     def __init__(self, name, value):
         self.name = name
@@ -399,6 +422,7 @@ class SportFollow1(Base):
         data = session.query(cls).all()
         session.close()
         result = [x.issue for x in data]
+        result.sort()
         return result
 
 
@@ -676,6 +700,7 @@ class SportFollow2(Base):
         data = session.query(cls).all()
         session.close()
         result = [x.issue for x in data]
+        result.sort()
         return result
 
 
@@ -953,6 +978,7 @@ class SportFollow3(Base):
         data = session.query(cls).all()
         session.close()
         result = [x.issue for x in data]
+        result.sort()
         return result
 
 
@@ -1068,6 +1094,7 @@ class SportResult(Base):
         data = session.query(cls).all()
         session.close()
         result = [x.issue for x in data]
+        result.sort()
         return result
 
 
@@ -1090,30 +1117,30 @@ class CaiYanShi(Base):
     issue = Column(Integer, primary_key=True)
 
     # attributes
-    save_a = Column(String)  # 金胆
-    save_b = Column(String)  # 银胆
-    save_c = Column(String)  # 铜胆
-    kills = Column(String)  # 排除
-    he = Column(String)  # 和值
-    span = Column(String)  # 跨度
-    mix5 = Column(String)  # 五码复式
-    mix6 = Column(String)  # 六码复式
-    mix7 = Column(String)  # 七码复式
-    multi6 = Column(String)  # 组选推荐
-    multi3 = Column(String)  # 组三推荐
+    save_a = Column(String(50))  # 金胆
+    save_b = Column(String(50))  # 银胆
+    save_c = Column(String(50))  # 铜胆
+    kills = Column(String(50))  # 排除
+    he = Column(String(50))  # 和值
+    span = Column(String(50))  # 跨度
+    mix5 = Column(String(50))  # 五码复式
+    mix6 = Column(String(50))  # 六码复式
+    mix7 = Column(String(50))  # 七码复式
+    multi6 = Column(String(500))  # 组选推荐
+    multi3 = Column(String(500))  # 组三推荐
 
     # verify attributes
-    v_save_a = Column(String)
-    v_save_b = Column(String)
-    v_save_c = Column(String)
-    v_kills = Column(String)
-    v_he = Column(String)
-    v_span = Column(String)
-    v_mix5 = Column(String)
-    v_mix6 = Column(String)
-    v_mix7 = Column(String)
-    v_multi6 = Column(String)
-    v_multi3 = Column(String)
+    v_save_a = Column(String(50))
+    v_save_b = Column(String(50))
+    v_save_c = Column(String(50))
+    v_kills = Column(String(50))
+    v_he = Column(String(50))
+    v_span = Column(String(50))
+    v_mix5 = Column(String(50))
+    v_mix6 = Column(String(50))
+    v_mix7 = Column(String(50))
+    v_multi6 = Column(String(50))
+    v_multi3 = Column(String(50))
 
     def set_attribute(self, issue: int, attribute_name: str, data: str):
         """
@@ -1191,30 +1218,30 @@ class DaiTouDaGe(Base):
     issue = Column(Integer, primary_key=True)
 
     # attributes
-    kills = Column(String)  # 杀码推荐
-    save1 = Column(String)  # 独胆预测
-    save2 = Column(String)  # 双胆预测
-    save3 = Column(String)  # 三胆预测
-    mix5 = Column(String)  # 五码复式
-    mix6 = Column(String)  # 六码复式
-    mix7 = Column(String)  # 七码复式
-    he = Column(String)  # 推荐和值
-    span = Column(String)  # 推荐跨度
-    multi6 = Column(String)  # 组选推荐
-    result_many = Column(String)  # 直选推荐
+    kills = Column(String(50))  # 杀码推荐
+    save1 = Column(String(50))  # 独胆预测
+    save2 = Column(String(50))  # 双胆预测
+    save3 = Column(String(50))  # 三胆预测
+    mix5 = Column(String(50))  # 五码复式
+    mix6 = Column(String(50))  # 六码复式
+    mix7 = Column(String(50))  # 七码复式
+    he = Column(String(50))  # 推荐和值
+    span = Column(String(50))  # 推荐跨度
+    multi6 = Column(String(500))  # 组选推荐
+    result_many = Column(String(500))  # 直选推荐
 
     # verify attributes
-    v_kills = Column(String)
-    v_save1 = Column(String)
-    v_save2 = Column(String)
-    v_save3 = Column(String)
-    v_mix5 = Column(String)
-    v_mix6 = Column(String)
-    v_mix7 = Column(String)
-    v_he = Column(String)
-    v_span = Column(String)
-    v_multi6 = Column(String)
-    v_result_many = Column(String)
+    v_kills = Column(String(50))
+    v_save1 = Column(String(50))
+    v_save2 = Column(String(50))
+    v_save3 = Column(String(50))
+    v_mix5 = Column(String(50))
+    v_mix6 = Column(String(50))
+    v_mix7 = Column(String(50))
+    v_he = Column(String(50))
+    v_span = Column(String(50))
+    v_multi6 = Column(String(50))
+    v_result_many = Column(String(50))
 
     def set_attribute(self, issue: int, attribute_name: str, data: str):
         """
@@ -1295,24 +1322,24 @@ class HuaWuQue(Base):
     issue = Column(Integer, primary_key=True)
 
     # attributes
-    save_location = Column(String)  # 定位胆码
-    position1 = Column(String)  # 百位
-    position2 = Column(String)  # 十位
-    position3 = Column(String)  # 个位
-    mix5 = Column(String)  # 5码复试
-    mix6 = Column(String)  # 6码复式
-    mix7 = Column(String)  # 7码复式
-    multi36 = Column(String)  # 组选推荐
+    save_location = Column(String(50))  # 定位胆码
+    position1 = Column(String(50))  # 百位
+    position2 = Column(String(50))  # 十位
+    position3 = Column(String(50))  # 个位
+    mix5 = Column(String(50))  # 5码复试
+    mix6 = Column(String(50))  # 6码复式
+    mix7 = Column(String(50))  # 7码复式
+    multi36 = Column(String(500))  # 组选推荐
 
     # verify attribute
-    v_save_location = Column(String)
-    v_position1 = Column(String)
-    v_position2 = Column(String)
-    v_position3 = Column(String)
-    v_mix5 = Column(String)
-    v_mix6 = Column(String)
-    v_mix7 = Column(String)
-    v_multi36 = Column(String)
+    v_save_location = Column(String(50))
+    v_position1 = Column(String(50))
+    v_position2 = Column(String(50))
+    v_position3 = Column(String(50))
+    v_mix5 = Column(String(50))
+    v_mix6 = Column(String(50))
+    v_mix7 = Column(String(50))
+    v_multi36 = Column(String(50))
 
     def set_attribute(self, issue: int, attribute_name: str, data: str):
         """
@@ -1387,32 +1414,32 @@ class QingQiuJuShi(Base):
     issue = Column(Integer, primary_key=True)
 
     # attributes
-    save1 = Column(String)  # 独胆
-    save2 = Column(String)  # 双胆
-    save3 = Column(String)  # 三胆
-    kill1 = Column(String)  # 杀一码
-    kill2 = Column(String)  # 杀二码
-    kill3 = Column(String)  # 杀三码
-    mix5 = Column(String)  # 五码
-    mix6 = Column(String)  # 六码
-    position_x = Column(String)  # 定位
-    he = Column(String)  # 和值
-    span = Column(String)  # 跨度
-    multi6 = Column(String)  # 组选
+    save1 = Column(String(50))  # 独胆
+    save2 = Column(String(50))  # 双胆
+    save3 = Column(String(50))  # 三胆
+    kill1 = Column(String(50))  # 杀一码
+    kill2 = Column(String(50))  # 杀二码
+    kill3 = Column(String(50))  # 杀三码
+    mix5 = Column(String(50))  # 五码
+    mix6 = Column(String(50))  # 六码
+    position_x = Column(String(50))  # 定位
+    he = Column(String(50))  # 和值
+    span = Column(String(50))  # 跨度
+    multi6 = Column(String(500))  # 组选
 
     # verify attributes
-    v_save1 = Column(String)
-    v_save2 = Column(String)
-    v_save3 = Column(String)
-    v_kill1 = Column(String)
-    v_kill2 = Column(String)
-    v_kill3 = Column(String)
-    v_mix5 = Column(String)
-    v_mix6 = Column(String)
-    v_position_x = Column(String)
-    v_he = Column(String)
-    v_span = Column(String)
-    v_multi6 = Column(String)
+    v_save1 = Column(String(50))
+    v_save2 = Column(String(50))
+    v_save3 = Column(String(50))
+    v_kill1 = Column(String(50))
+    v_kill2 = Column(String(50))
+    v_kill3 = Column(String(50))
+    v_mix5 = Column(String(50))
+    v_mix6 = Column(String(50))
+    v_position_x = Column(String(50))
+    v_he = Column(String(50))
+    v_span = Column(String(50))
+    v_multi6 = Column(String(50))
 
     def set_attribute(self, issue: int, attribute_name: str, data: str):
         """
@@ -1477,28 +1504,28 @@ class ShiNaJiuWen(Base):
     issue = Column(Integer, primary_key=True)
 
     # attributes
-    save3 = Column(String)  # 胆码
-    mix4 = Column(String)  # 四码
-    mix5 = Column(String)  # 五码复式
-    mix6 = Column(String)  # 六码复式
-    mix7 = Column(String)  # 七码复式
-    position1 = Column(String)  # 百位定位推荐
-    position2 = Column(String)  # 十位定位推荐
-    position3 = Column(String)  # 个位定位推荐
-    result_many = Column(String)  # 直选精选
-    multi36 = Column(String)  # 组选大底
+    save3 = Column(String(50))  # 胆码
+    mix4 = Column(String(50))  # 四码
+    mix5 = Column(String(50))  # 五码复式
+    mix6 = Column(String(50))  # 六码复式
+    mix7 = Column(String(50))  # 七码复式
+    position1 = Column(String(50))  # 百位定位推荐
+    position2 = Column(String(50))  # 十位定位推荐
+    position3 = Column(String(50))  # 个位定位推荐
+    result_many = Column(String(500))  # 直选精选
+    multi36 = Column(String(500))  # 组选大底
 
     # verify attribute
-    v_save3 = Column(String)
-    v_mix4 = Column(String)
-    v_mix5 = Column(String)
-    v_mix6 = Column(String)
-    v_mix7 = Column(String)
-    v_position1 = Column(String)
-    v_position2 = Column(String)
-    v_position3 = Column(String)
-    v_result_many = Column(String)
-    v_multi36 = Column(String)
+    v_save3 = Column(String(50))
+    v_mix4 = Column(String(50))
+    v_mix5 = Column(String(50))
+    v_mix6 = Column(String(50))
+    v_mix7 = Column(String(50))
+    v_position1 = Column(String(50))
+    v_position2 = Column(String(50))
+    v_position3 = Column(String(50))
+    v_result_many = Column(String(50))
+    v_multi36 = Column(String(50))
 
     def set_attribute(self, issue: int, attribute_name: str, data: str):
         """
@@ -1577,26 +1604,26 @@ class WanCaiLaoTou(Base):
     issue = Column(Integer, primary_key=True)
 
     # attributes
-    save1 = Column(String)  # 独胆
-    save2 = Column(String)  # 双胆
-    save3 = Column(String)  # 三胆
-    mix5 = Column(String)  # 五码
-    mix6 = Column(String)  # 六码
-    mix7 = Column(String)  # 七码
-    he = Column(String)  # 和值
-    span = Column(String)  # 跨度
-    multi6 = Column(String)  # 组六号码推荐
+    save1 = Column(String(50))  # 独胆
+    save2 = Column(String(50))  # 双胆
+    save3 = Column(String(50))  # 三胆
+    mix5 = Column(String(50))  # 五码
+    mix6 = Column(String(50))  # 六码
+    mix7 = Column(String(50))  # 七码
+    he = Column(String(50))  # 和值
+    span = Column(String(50))  # 跨度
+    multi6 = Column(String(500))  # 组六号码推荐
 
     # verify attributes
-    v_save1 = Column(String)
-    v_save2 = Column(String)
-    v_save3 = Column(String)
-    v_mix5 = Column(String)
-    v_mix6 = Column(String)
-    v_mix7 = Column(String)
-    v_he = Column(String)
-    v_span = Column(String)
-    v_multi6 = Column(String)
+    v_save1 = Column(String(50))
+    v_save2 = Column(String(50))
+    v_save3 = Column(String(50))
+    v_mix5 = Column(String(50))
+    v_mix6 = Column(String(50))
+    v_mix7 = Column(String(50))
+    v_he = Column(String(50))
+    v_span = Column(String(50))
+    v_multi6 = Column(String(50))
 
     def set_attribute(self, issue: int, attribute_name: str, data: str):
         """
@@ -1673,28 +1700,28 @@ class XiaoYanZi(Base):
     issue = Column(Integer, primary_key=True)
 
     # attributes
-    save1 = Column(String)  # 独胆预测
-    save2 = Column(String)  # 双胆预测
-    save3 = Column(String)  # 三胆预测
-    mix5 = Column(String)  # 五码复式
-    mix6 = Column(String)  # 六码复式
-    mix7 = Column(String)  # 七码复式
-    he = Column(String)  # 推荐和值
-    span = Column(String)  # 推荐跨度
-    kills = Column(String)  # 排除号码
-    multi6 = Column(String)  # 组选号码
+    save1 = Column(String(50))  # 独胆预测
+    save2 = Column(String(50))  # 双胆预测
+    save3 = Column(String(50))  # 三胆预测
+    mix5 = Column(String(50))  # 五码复式
+    mix6 = Column(String(50))  # 六码复式
+    mix7 = Column(String(50))  # 七码复式
+    he = Column(String(50))  # 推荐和值
+    span = Column(String(50))  # 推荐跨度
+    kills = Column(String(50))  # 排除号码
+    multi6 = Column(String(500))  # 组选号码
 
     # verify attributes
-    v_save1 = Column(String)
-    v_save2 = Column(String)
-    v_save3 = Column(String)
-    v_mix5 = Column(String)
-    v_mix6 = Column(String)
-    v_mix7 = Column(String)
-    v_he = Column(String)
-    v_span = Column(String)
-    v_kills = Column(String)
-    v_multi6 = Column(String)
+    v_save1 = Column(String(50))
+    v_save2 = Column(String(50))
+    v_save3 = Column(String(50))
+    v_mix5 = Column(String(50))
+    v_mix6 = Column(String(50))
+    v_mix7 = Column(String(50))
+    v_he = Column(String(50))
+    v_span = Column(String(50))
+    v_kills = Column(String(50))
+    v_multi6 = Column(String(50))
 
     def set_attribute(self, issue: int, attribute_name: str, data: str):
         """
@@ -1773,32 +1800,32 @@ class YueYeFeiLong(Base):
     issue = Column(Integer, primary_key=True)
 
     # attributes
-    save1 = Column(String)  # 独胆
-    save2 = Column(String)  # 双胆
-    save3 = Column(String)  # 三胆
-    kill1 = Column(String)  # 杀一码
-    kill2 = Column(String)  # 杀二码
-    kill3 = Column(String)  # 杀三码
-    mix5 = Column(String)  # 五码
-    mix6 = Column(String)  # 六码
-    position_x = Column(String)  # 定位
-    he = Column(String)  # 和值
-    span = Column(String)  # 跨度
-    multi6 = Column(String)  # 组选
+    save1 = Column(String(50))  # 独胆
+    save2 = Column(String(50))  # 双胆
+    save3 = Column(String(50))  # 三胆
+    kill1 = Column(String(50))  # 杀一码
+    kill2 = Column(String(50))  # 杀二码
+    kill3 = Column(String(50))  # 杀三码
+    mix5 = Column(String(50))  # 五码
+    mix6 = Column(String(50))  # 六码
+    position_x = Column(String(50))  # 定位
+    he = Column(String(50))  # 和值
+    span = Column(String(50))  # 跨度
+    multi6 = Column(String(500))  # 组选
 
     # verify attributes
-    v_save1 = Column(String)
-    v_save2 = Column(String)
-    v_save3 = Column(String)
-    v_kill1 = Column(String)
-    v_kill2 = Column(String)
-    v_kill3 = Column(String)
-    v_mix5 = Column(String)
-    v_mix6 = Column(String)
-    v_position_x = Column(String)
-    v_he = Column(String)
-    v_span = Column(String)
-    v_multi6 = Column(String)
+    v_save1 = Column(String(50))
+    v_save2 = Column(String(50))
+    v_save3 = Column(String(50))
+    v_kill1 = Column(String(50))
+    v_kill2 = Column(String(50))
+    v_kill3 = Column(String(50))
+    v_mix5 = Column(String(50))
+    v_mix6 = Column(String(50))
+    v_position_x = Column(String(50))
+    v_he = Column(String(50))
+    v_span = Column(String(50))
+    v_multi6 = Column(String(50))
 
     def set_attribute(self, issue: int, attribute_name: str, data: str):
         """
@@ -1882,28 +1909,28 @@ class ZiYunJian(Base):
     issue = Column(Integer, primary_key=True)
 
     # attributes
-    position5_1 = Column(String)  # 555复式 百位
-    position5_2 = Column(String)  # 555复式 十位
-    position5_3 = Column(String)  # 555复式 个位
-    position3_1 = Column(String)  # 333复式 百位
-    position3_2 = Column(String)  # 333复式 十位
-    position3_3 = Column(String)  # 333复式 个位
-    save3 = Column(String)  # 三胆
-    mix4 = Column(String)  # 四码
-    mix5 = Column(String)  # 五码
-    multi36 = Column(String)  # 直,组推荐
+    position5_1 = Column(String(50))  # 555复式 百位
+    position5_2 = Column(String(50))  # 555复式 十位
+    position5_3 = Column(String(50))  # 555复式 个位
+    position3_1 = Column(String(50))  # 333复式 百位
+    position3_2 = Column(String(50))  # 333复式 十位
+    position3_3 = Column(String(50))  # 333复式 个位
+    save3 = Column(String(50))  # 三胆
+    mix4 = Column(String(50))  # 四码
+    mix5 = Column(String(50))  # 五码
+    multi36 = Column(String(500))  # 直,组推荐
 
     # verify attributes
-    v_position5_1 = Column(String)
-    v_position5_2 = Column(String)
-    v_position5_3 = Column(String)
-    v_position3_1 = Column(String)
-    v_position3_2 = Column(String)
-    v_position3_3 = Column(String)
-    v_save3 = Column(String)
-    v_mix4 = Column(String)
-    v_mix5 = Column(String)
-    v_multi36 = Column(String)
+    v_position5_1 = Column(String(50))
+    v_position5_2 = Column(String(50))
+    v_position5_3 = Column(String(50))
+    v_position3_1 = Column(String(50))
+    v_position3_2 = Column(String(50))
+    v_position3_3 = Column(String(50))
+    v_save3 = Column(String(50))
+    v_mix4 = Column(String(50))
+    v_mix5 = Column(String(50))
+    v_multi36 = Column(String(50))
 
     def set_attribute(self, issue: int, attribute_name: str, data: str):
         """
@@ -2069,21 +2096,22 @@ class SportMiss(Base):
         data = session.query(cls).all()
         session.close()
         result = [x.issue for x in data]
+        result.sort()
         return result
 
 
 class SportVerify(Base):
     __tablename__ = 'verifies'
-    inumabc = Column(String, primary_key=True)
+    inumabc = Column(String(50), primary_key=True)
     issue = Column(Integer)
     num = Column(Integer)
-    abc = Column(String)
-    result = Column(String)
+    abc = Column(String(50))
+    result = Column(String(50))
     score = Column(Float)
     num1 = Column(Integer)
     num2 = Column(Integer)
     num3 = Column(Integer)
-    verify = Column(String)
+    verify = Column(String(50))
 
     def __init__(self, inumabc, issue, num, abc, result, score):
         super().__init__()
@@ -2098,17 +2126,247 @@ class SportVerify(Base):
     def add_score(cls, inumabc, issue, num, abc, result, score):
         sess = get_session_sport()
         ins = cls(inumabc, issue, num, abc, result, score)
+        issues_all = SportNumber.get_issues()
+        if issue in issues_all:
+            numbers = SportNumber.get_one(issue)
+            if int(num) in numbers[1:]:
+                if result == 'y':
+                    ins.verify = 'y'
+                else:
+                    ins.verify = 'n'
+            else:
+                if result == 'y':
+                    ins.verify = 'n'
+                else:
+                    ins.verify = 'y'
+        else:
+            ins.verify = None
         sess.merge(ins)
         sess.commit()
         sess.close()
-        print(f">>> add score: inumabc: {inumabc}, issue: {issue}, num: {num}, abc: {abc}, result: {result}, score: {score}")
+        print(
+            f">>> add score: inumabc: {inumabc}, issue: {issue}, num: {num}, abc: {abc}, result: {result}, score: {score}, verify: {ins.verify}")
 
 
+class SportNumber5(Base):
+    """ numbers@p3.db """
+    __tablename__ = 'number5'
+
+    issue = Column(Integer, primary_key=True)
+    num1 = Column(Integer, nullable=False)
+    num2 = Column(Integer, nullable=False)
+    num3 = Column(Integer, nullable=False)
+    num4 = Column(Integer, nullable=False)
+    num5 = Column(Integer, nullable=False)
+
+    def __init__(self, data_list: list):
+        self.issue, self.num1, self.num2, self.num3, self.num4, self.num5 = data_list
+
+    @classmethod
+    def get_issues(cls):
+        """get issues[list]"""
+        session = get_session_sport()
+        i = session.query(cls).all()
+        result = [x.issue for x in i]
+        result.sort()
+        session.close()
+        return result
+
+    @classmethod
+    def get_all(cls):
+        """get all [[issue, num1, num2, num3, num4, num5]... ]"""
+        session = get_session_sport()
+        data = session.query(cls).all()
+        session.close()
+        return [[x.issue, x.num1, x.num2, x.num3, x.num4, x.num5] for x in data]
+
+    @classmethod
+    def get_numbers(cls):
+        """get numbers [[issue, num1, num2, num3]... ]"""
+        session = get_session_sport()
+        data = session.query(cls).all()
+        session.close()
+        result = [[x.issue, x.num1, x.num2, x.num3, x.num4, x.num5] for x in data]
+        return result
+
+    @classmethod
+    def get_one(cls, issue_number: int):
+        """获取对应 issue 的号码列表 [issue, num1, num2, num3]"""
+        session = get_session_sport()
+        data = session.query(cls).get(issue_number)
+        session.close()
+        return [data.issue, data.num1, data.num2, data.num3, data.num4, data.num5]
+
+    @classmethod
+    def add_number(cls, p_issue: str, p_numbers: list):
+        """添加一条记录"""
+        session = get_session_sport()
+        ins = cls([p_issue] + p_numbers)
+        session.merge(ins)
+        session.commit()
+        session.close()
+        print(f">>> merge kill in kills:{p_issue} - {p_numbers}")
 
 
+class SportFollowX(Base):
+    __abstract__ = True
+
+    issue = Column(Integer, primary_key=True)
+    num = Column(Integer, nullable=False)
+    next1 = Column(Integer)
+    next2 = Column(Integer)
+    next3 = Column(Integer)
+    f0 = Column(Integer)
+    f1 = Column(Integer)
+    f2 = Column(Integer)
+    f3 = Column(Integer)
+    f4 = Column(Integer)
+    f5 = Column(Integer)
+    f6 = Column(Integer)
+    f7 = Column(Integer)
+    f8 = Column(Integer)
+    f9 = Column(Integer)
+    c0 = Column(Float)
+    c1 = Column(Float)
+    c2 = Column(Float)
+    c3 = Column(Float)
+    c4 = Column(Float)
+    c5 = Column(Float)
+    c6 = Column(Float)
+    c7 = Column(Float)
+    c8 = Column(Float)
+    c9 = Column(Float)
+
+    # def __init__(self, issue, num) -> None:
+    #     super().__init__()
+    #     self.issue = issue
+    #     self.num = num
+
+    @classmethod
+    def get_follow_09(cls):
+        session = get_session_sport()
+        data = session.query(cls).all()
+        result = {}
+        for t in data:
+            result[t.issue] = [t.f0, t.f1, t.f2, t.f3, t.f, t.f5, t.f6, t.f7, t.f8, t.f9]
+        return result
+
+    @classmethod
+    def get_change_09(cls):
+        session = get_session_sport()
+        data = session.query(cls).all()
+        result = {}
+        for t in data:
+            result[t.issue] = [t.c0, t.c1, t.c2, t.c3, t.c, t.c5, t.c6, t.c7, t.c8, t.c9]
+        return result
+
+    @classmethod
+    def get_nums(cls):
+        """
+        [[issue, num],...]
+        """
+        session = get_session_sport()
+        data = session.query(cls).all()
+        session.close()
+        result = [[x.issue, x.num] for x in data]
+        return result
+
+    @classmethod
+    def get_number_and_next(cls):
+        """
+        [[issue, num, next1, next2, next3],...]
+        """
+        session = get_session_sport()
+        data = session.query(cls).all()
+        session.close()
+        result = [[x.issue, x.num, x.next1, x.next2, x.next3] for x in data]
+        return result
+
+    @classmethod
+    def get_all(cls):
+        """
+        获取所有的数据
+        """
+        session = get_session_sport()
+        data = session.query(cls).all()
+        session.close()
+        result = [[
+            x.issue,
+            x.num,
+            x.f0,
+            x.f1,
+            x.f2,
+            x.f3,
+            x.f4,
+            x.f5,
+            x.f6,
+            x.f7,
+            x.f8,
+            x.f9,
+            x.c0,
+            x.c1,
+            x.c2,
+            x.c3,
+            x.c4,
+            x.c5,
+            x.c6,
+            x.c7,
+            x.c8,
+            x.c9
+        ] for x in data]
+        return result
+
+    @classmethod
+    def get_issues(cls):
+        """get issues"""
+        session = get_session_sport()
+        data = session.query(cls).all()
+        session.close()
+        result = [x.issue for x in data]
+        result.sort()
+        return result
 
 
+class SportFollowA(SportFollowX):
+    __tablename__ = 'followa'
+
+    def __init__(self, issue, num) -> None:
+        super().__init__()
+        self.issue = issue
+        self.num = num
 
 
+class SportFollowB(SportFollowX):
+    __tablename__ = 'followb'
+
+    def __init__(self, issue, num) -> None:
+        super().__init__()
+        self.issue = issue
+        self.num = num
 
 
+class SportFollowC(SportFollowX):
+    __tablename__ = 'followc'
+
+    def __init__(self, issue, num) -> None:
+        super().__init__()
+        self.issue = issue
+        self.num = num
+
+
+class SportFollowD(SportFollowX):
+    __tablename__ = 'followd'
+
+    def __init__(self, issue, num) -> None:
+        super().__init__()
+        self.issue = issue
+        self.num = num
+
+
+class SportFollowE(SportFollowX):
+    __tablename__ = 'followe'
+
+    def __init__(self, issue, num) -> None:
+        super().__init__()
+        self.issue = issue
+        self.num = num
